@@ -1,7 +1,7 @@
-export CONDA_EXE='D:\bld\conda_1576178757525\_h_env\Scripts\conda.exe'
+export CONDA_EXE='D:\bld\conda_1579914728944\_h_env\Scripts\conda.exe'
 export _CE_M=''
 export _CE_CONDA=''
-export CONDA_PYTHON_EXE='D:\bld\conda_1576178757525\_h_env\python.exe'
+export CONDA_PYTHON_EXE='D:\bld\conda_1579914728944\_h_env\python.exe'
 
 # Copyright (C) 2012 Anaconda, Inc
 # SPDX-License-Identifier: BSD-3-Clause
@@ -52,11 +52,11 @@ __conda_activate() {
     \local ask_conda
     CONDA_INTERNAL_OLDPATH="${PATH}"
     __add_sys_prefix_to_path
-    ask_conda="$(PS1="$PS1" "$CONDA_EXE" $_CE_M $_CE_CONDA shell.posix "$cmd" "$@")" || $?
+    ask_conda="$(PS1="$PS1" "$CONDA_EXE" $_CE_M $_CE_CONDA shell.posix "$cmd" "$@")" || \return $?
     rc=$?
     PATH="${CONDA_INTERNAL_OLDPATH}"
     \eval "$ask_conda"
-    if [[ $rc != 0 ]]; then
+    if [ $rc != 0 ]; then
         \export PATH
     fi
     __conda_hashr
