@@ -7,6 +7,9 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import os
 from os.path import abspath, dirname
 import sys
+
+from json import JSONEncoder
+
 # This hack is from http://kmike.ru/python-with-strings-attached/
 # It is needed ro prevent str() conversion of %r. Against general
 # advice, we return `unicode` from various things on Python 2,
@@ -26,7 +29,7 @@ __all__ = (
 )
 
 __name__ = "conda"
-__version__ = "4.8.0"
+__version__ = "4.8.2"
 __author__ = "Anaconda, Inc."
 __email__ = "conda@continuum.io"
 __license__ = "BSD-3-Clause"
@@ -172,3 +175,11 @@ def conda_signal_handler(signum, frame):
 
     from .exceptions import CondaSignalInterrupt
     raise CondaSignalInterrupt(signum)
+
+
+def _default(self, obj):
+    return getattr(obj.__class__, "to_json", _default.default)(obj)
+
+
+_default.default = JSONEncoder().default
+JSONEncoder.default = _default
